# Image to ASCII

[![PyPI version](https://badge.fury.io/py/image-ascii.svg)](https://badge.fury.io/py/image-ascii)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/badge/python-3.6%2B-blue.svg)](https://www.python.org/downloads/)
[![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Contributions Welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/yourusername/image-ascii/issues)
![Commit Activity](https://img.shields.io/github/commit-activity/y/tianhukj/image-ascii)
![GitHub Watchers](https://img.shields.io/github/watchers/tianhukj/image-ascii?style=social)
![GitHub Stars](https://img.shields.io/github/stars/tianhukj/image-ascii?style=social)
[![Buy Me a Coffee](https://img.shields.io/badge/Donate-Buy%20Me%20A%20Coffee-FF813F.svg?logo=buy-me-a-coffee)](https://www.buymeacoffee.com/tianhukj)
[![Python package](https://github.com/tianhukj/image-ascii/actions/workflows/python-package.yml/badge.svg)](https://github.com/tianhukj/image-ascii/actions/workflows/python-package.yml)


#### A simple Python package to convert images to ASCII art.

## Installation

```bash
pip install image-ascii
```

## Contributing
Contributions are welcome! If you have any suggestions or find any issues, feel free to open an issue or submit a pull request.

### Clone the repository
```bash
git clone https://github.com/yourusername/image-ascii.git
```

## License
This project is licensed under the MIT License. See the LICENSE![](/LICENSE) file for details.
